<?php
/**
 * @copyright Copyright (C) 2010-2022, the Friendica project
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * Main view structure configuration file.
 *
 * Here are described all the view Friendica needs to work.
 *
 * Syntax (braces indicate optionale values):
 * "<view name>" => [
 *	"fields" => [
 *		"<field name>" => ["table", "field"],
 *		"<field name>" => "SQL expression",
 *		...
 *	],
 *	"query" => "FROM `table` INNER JOIN `other-table` ..."
 *	],
 * ],
 *
 * If you need to make any change, make sure to increment the DB_UPDATE_VERSION constant value in dbstructure.config.php.
 *
 */

 return [
	"application-view" => [
		"fields" => [
			"id" => ["application", "id"],
			"uid" => ["application-token", "uid"],
			"name" => ["application", "name"],
			"redirect_uri" => ["application", "redirect_uri"],
			"website" => ["application", "website"],
			"client_id" => ["application", "client_id"],
			"client_secret" => ["application", "client_secret"],
			"code" => ["application-token", "code"],
			"access_token" => ["application-token", "access_token"],
			"created_at" => ["application-token", "created_at"],
			"scopes" => ["application-token", "scopes"],
			"read" => ["application-token", "read"],
			"write" => ["application-token", "write"],
			"follow" => ["application-token", "follow"],
			"push" => ["application-token", "push"],
		],
		"query" => "FROM `application-token`
			INNER JOIN `application` ON `application-token`.`application-id` = `application`.`id`"
	],
	"post-user-view" => [
		"fields" => [
			"id" => ["post-user", "id"],
			"post-user-id" => ["post-user", "id"],
			"uid" => ["post-user", "uid"],
			"parent" => ["parent-post", "id"],
			"uri" => ["item-uri", "uri"],
			"uri-id" => ["post-user", "uri-id"],
			"parent-uri" => ["parent-item-uri", "uri"],
			"parent-uri-id" => ["post-user", "parent-uri-id"],
			"thr-parent" => ["thr-parent-item-uri", "uri"],
			"thr-parent-id" => ["post-user", "thr-parent-id"],
			"conversation" => ["conversation-item-uri", "uri"],
			"conversation-id" => ["post-thread-user", "conversation-id"],
			"quote-uri" => ["quote-item-uri", "uri"],
			"quote-uri-id" => ["post-content", "quote-uri-id"],
			"guid" => ["item-uri", "guid"],
			"wall" => ["post-user", "wall"],
			"gravity" => ["post-user", "gravity"],
			"extid" => ["external-item-uri", "uri"],
			"external-id" => ["post-user", "external-id"],
			"created" => ["post-user", "created"],
			"edited" => ["post-user", "edited"],
			"commented" => ["post-thread-user", "commented"],
			"received" => ["post-user", "received"],
			"changed" => ["post-thread-user", "changed"],
			"post-type" => ["post-user", "post-type"],
			"post-reason" => ["post-user", "post-reason"],
			"private" => ["post-user", "private"],
			"pubmail" => ["post-thread-user", "pubmail"],
			"visible" => ["post-user", "visible"],
			"starred" => ["post-thread-user", "starred"],
			"unseen" => ["post-user", "unseen"],
			"deleted" => ["post-user", "deleted"],
			"origin" => ["post-user", "origin"],
			"parent-origin" => ["post-thread-user", "origin"],
			"mention" => ["post-thread-user", "mention"],
			"global" => ["post-user", "global"],
			"featured" => "EXISTS(SELECT `type` FROM `post-collection` WHERE `type` = 0 AND `uri-id` = `post-user`.`uri-id`)",
			"network" => ["post-user", "network"],
			"protocol" => ["post-user", "protocol"],
			"vid" => ["post-user", "vid"],
			"psid" => ["post-user", "psid"],
			"verb" => "IF (`post-user`.`vid` IS NULL, '', `verb`.`name`)",
			"title" => ["post-content", "title"],
			"content-warning" => ["post-content", "content-warning"],
			"raw-body" => ["post-content", "raw-body"],
			"body" => "IFNULL (`post-content`.`body`, '')",
			"rendered-hash" => ["post-content", "rendered-hash"],
			"rendered-html" => ["post-content", "rendered-html"],
			"language" => ["post-content", "language"],
			"plink" => ["post-content", "plink"],
			"location" => ["post-content", "location"],
			"coord" => ["post-content", "coord"],
			"app" => ["post-content", "app"],
			"object-type" => ["post-content", "object-type"],
			"object" => ["post-content", "object"],
			"target-type" => ["post-content", "target-type"],
			"target" => ["post-content", "target"],
			"resource-id" => ["post-content", "resource-id"],
			"contact-id" => ["post-user", "contact-id"],
			"contact-uri-id" => ["contact", "uri-id"],
			"contact-link" => ["contact", "url"],
			"contact-addr" => ["contact", "addr"],
			"contact-name" => ["contact", "name"],
			"contact-nick" => ["contact", "nick"],
			"contact-avatar" => ["contact", "thumb"],
			"contact-network" => ["contact", "network"],
			"contact-blocked" => ["contact", "blocked"],
			"contact-hidden" => ["contact", "hidden"],
			"contact-readonly" => ["contact", "readonly"],
			"contact-archive" => ["contact", "archive"],
			"contact-pending" => ["contact", "pending"],
			"contact-rel" => ["contact", "rel"],
			"contact-uid" => ["contact", "uid"],
			"contact-contact-type" => ["contact", "contact-type"],
			"writable" => "IF (`post-user`.`network` IN ('apub', 'dfrn', 'dspr', 'stat'), true, `contact`.`writable`)",
			"self" => ["contact", "self"],
			"cid" => ["contact", "id"],
			"alias" => ["contact", "alias"],
			"photo" => ["contact", "photo"],
			"name-date" => ["contact", "name-date"],
			"uri-date" => ["contact", "uri-date"],
			"avatar-date" => ["contact", "avatar-date"],
			"thumb" => ["contact", "thumb"],
			"author-id" => ["post-user", "author-id"],
			"author-uri-id" => ["author", "uri-id"],
			"author-link" => ["author", "url"],
			"author-addr" => ["author", "addr"],
			"author-name" => "IF (`contact`.`url` = `author`.`url` AND `contact`.`name` != '', `contact`.`name`, `author`.`name`)",
			"author-nick" => ["author", "nick"],
			"author-avatar" => "IF (`contact`.`url` = `author`.`url` AND `contact`.`thumb` != '', `contact`.`thumb`, `author`.`thumb`)",
			"author-network" => ["author", "network"],
			"author-blocked" => ["author", "blocked"],
			"author-hidden" => ["author", "hidden"],
			"author-updated" => ["author", "updated"],
			"author-gsid" => ["author", "gsid"],
			"author-uri-id" => ["author", "uri-id"],
			"owner-id" => ["post-user", "owner-id"],
			"owner-uri-id" => ["owner", "uri-id"],
			"owner-link" => ["owner", "url"],
			"owner-addr" => ["owner", "addr"],
			"owner-name" => "IF (`contact`.`url` = `owner`.`url` AND `contact`.`name` != '', `contact`.`name`, `owner`.`name`)",
			"owner-nick" => ["owner", "nick"],
			"owner-avatar" => "IF (`contact`.`url` = `owner`.`url` AND `contact`.`thumb` != '', `contact`.`thumb`, `owner`.`thumb`)",
			"owner-network" => ["owner", "network"],
			"owner-blocked" => ["owner", "blocked"],
			"owner-hidden" => ["owner", "hidden"],
			"owner-updated" => ["owner", "updated"],
			"owner-contact-type" => ["owner", "contact-type"],
			"causer-id" => ["post-user", "causer-id"],
			"causer-uri-id" => ["causer", "uri-id"],
			"causer-link" => ["causer", "url"],
			"causer-addr" => ["causer", "addr"],
			"causer-name" => ["causer", "name"],
			"causer-nick" => ["causer", "nick"],
			"causer-avatar" => ["causer", "thumb"],
			"causer-network" => ["causer", "network"],
			"causer-blocked" => ["causer", "blocked"],
			"causer-hidden" => ["causer", "hidden"],
			"causer-contact-type" => ["causer", "contact-type"],
			"postopts" => ["post-delivery-data", "postopts"],
			"inform" => ["post-delivery-data", "inform"],
			"delivery_queue_count" => ["post-delivery-data", "queue_count"],
			"delivery_queue_done" => ["post-delivery-data", "queue_done"],
			"delivery_queue_failed" => ["post-delivery-data", "queue_failed"],
			"allow_cid" => "IF (`post-user`.`psid` IS NULL, '', `permissionset`.`allow_cid`)",
			"allow_gid" => "IF (`post-user`.`psid` IS NULL, '', `permissionset`.`allow_gid`)",
			"deny_cid" => "IF (`post-user`.`psid` IS NULL, '', `permissionset`.`deny_cid`)",
			"deny_gid" => "IF (`post-user`.`psid` IS NULL, '', `permissionset`.`deny_gid`)",
			"event-id" => ["post-user", "event-id"],
			"event-created" => ["event", "created"],
			"event-edited" => ["event", "edited"],
			"event-start" => ["event", "start"],
			"event-finish" => ["event", "finish"],
			"event-summary" => ["event", "summary"],
			"event-desc" => ["event", "desc"],
			"event-location" => ["event", "location"],
			"event-type" => ["event", "type"],
			"event-nofinish" => ["event", "nofinish"],
			"event-ignore" => ["event", "ignore"],
			"question-id" => ["post-question", "id"],
			"question-multiple" => ["post-question", "multiple"],
			"question-voters" => ["post-question", "voters"],
			"question-end-time" => ["post-question", "end-time"],
			"has-categories" => "EXISTS(SELECT `uri-id` FROM `post-category` WHERE `post-category`.`uri-id` = `post-user`.`uri-id` AND `post-category`.`uid` = `post-user`.`uid`)",
			"has-media" => "EXISTS(SELECT `id` FROM `post-media` WHERE `post-media`.`uri-id` = `post-user`.`uri-id`)",
			"signed_text" => ["diaspora-interaction", "interaction"],
			"parent-guid" => ["parent-item-uri", "guid"],
			"parent-network" => ["parent-post", "network"],
			"parent-author-id" => ["parent-post", "author-id"],
			"parent-author-link" => ["parent-post-author", "url"],
			"parent-author-name" => ["parent-post-author", "name"],
			"parent-author-nick" => ["parent-post-author", "nick"],
			"parent-author-network" => ["parent-post-author", "network"],
			"parent-author-blocked" => ["parent-post-author", "blocked"],
			"parent-author-hidden" => ["parent-post-author", "hidden"],
		],
		"query" => "FROM `post-user`
			STRAIGHT_JOIN `post-thread-user` ON `post-thread-user`.`uri-id` = `post-user`.`parent-uri-id` AND `post-thread-user`.`uid` = `post-user`.`uid`
			STRAIGHT_JOIN `contact` ON `contact`.`id` = `post-user`.`contact-id`
			STRAIGHT_JOIN `contact` AS `author` ON `author`.`id` = `post-user`.`author-id`
			STRAIGHT_JOIN `contact` AS `owner` ON `owner`.`id` = `post-user`.`owner-id`
			LEFT JOIN `contact` AS `causer` ON `causer`.`id` = `post-user`.`causer-id`
			LEFT JOIN `item-uri` ON `item-uri`.`id` = `post-user`.`uri-id`
			LEFT JOIN `item-uri` AS `thr-parent-item-uri` ON `thr-parent-item-uri`.`id` = `post-user`.`thr-parent-id`
			LEFT JOIN `item-uri` AS `parent-item-uri` ON `parent-item-uri`.`id` = `post-user`.`parent-uri-id`
			LEFT JOIN `item-uri` AS `conversation-item-uri` ON `conversation-item-uri`.`id` = `post-thread-user`.`conversation-id`
			LEFT JOIN `item-uri` AS `external-item-uri` ON `external-item-uri`.`id` = `post-user`.`external-id`
			LEFT JOIN `verb` ON `verb`.`id` = `post-user`.`vid`
			LEFT JOIN `event` ON `event`.`id` = `post-user`.`event-id`
			LEFT JOIN `diaspora-interaction` ON `diaspora-interaction`.`uri-id` = `post-user`.`uri-id`
			LEFT JOIN `post-content` ON `post-content`.`uri-id` = `post-user`.`uri-id`
			LEFT JOIN `item-uri` AS `quote-item-uri` ON `quote-item-uri`.`id` = `post-content`.`quote-uri-id`
			LEFT JOIN `post-delivery-data` ON `post-delivery-data`.`uri-id` = `post-user`.`uri-id` AND `post-user`.`origin`
			LEFT JOIN `post-question` ON `post-question`.`uri-id` = `post-user`.`uri-id`
			LEFT JOIN `permissionset` ON `permissionset`.`id` = `post-user`.`psid`
			LEFT JOIN `post-user` AS `parent-post` ON `parent-post`.`uri-id` = `post-user`.`parent-uri-id` AND `parent-post`.`uid` = `post-user`.`uid`
			LEFT JOIN `contact` AS `parent-post-author` ON `parent-post-author`.`id` = `parent-post`.`author-id`"
	],
	"post-thread-user-view" => [
		"fields" => [
			"id" => ["post-user", "id"],
			"post-user-id" => ["post-user", "id"],
			"uid" => ["post-thread-user", "uid"],
			"parent" => ["parent-post", "id"],
			"uri" => ["item-uri", "uri"],
			"uri-id" => ["post-thread-user", "uri-id"],
			"parent-uri" => ["parent-item-uri", "uri"],
			"parent-uri-id" => ["post-user", "parent-uri-id"],
			"thr-parent" => ["thr-parent-item-uri", "uri"],
			"thr-parent-id" => ["post-user", "thr-parent-id"],
			"conversation" => ["conversation-item-uri", "uri"],
			"conversation-id" => ["post-thread-user", "conversation-id"],
			"quote-uri" => ["quote-item-uri", "uri"],
			"quote-uri-id" => ["post-content", "quote-uri-id"],
			"guid" => ["item-uri", "guid"],
			"wall" => ["post-thread-user", "wall"],
			"gravity" => ["post-user", "gravity"],
			"extid" => ["external-item-uri", "uri"],
			"external-id" => ["post-user", "external-id"],
			"created" => ["post-thread-user", "created"],
			"edited" => ["post-user", "edited"],
			"commented" => ["post-thread-user", "commented"],
			"received" => ["post-thread-user", "received"],
			"changed" => ["post-thread-user", "changed"],
			"post-type" => ["post-user", "post-type"],
			"post-reason" => ["post-user", "post-reason"],
			"private" => ["post-user", "private"],
			"pubmail" => ["post-thread-user", "pubmail"],
			"ignored" => ["post-thread-user", "ignored"],
			"visible" => ["post-user", "visible"],
			"starred" => ["post-thread-user", "starred"],
			"unseen" => ["post-thread-user", "unseen"],
			"deleted" => ["post-user", "deleted"],
			"origin" => ["post-thread-user", "origin"],
			"mention" => ["post-thread-user", "mention"],
			"global" => ["post-user", "global"],
			"featured" => "EXISTS(SELECT `type` FROM `post-collection` WHERE `type` = 0 AND `uri-id` = `post-thread-user`.`uri-id`)",
			"network" => ["post-thread-user", "network"],
			"vid" => ["post-user", "vid"],
			"psid" => ["post-thread-user", "psid"],
			"verb" => "IF (`post-user`.`vid` IS NULL, '', `verb`.`name`)",
			"title" => ["post-content", "title"],
			"content-warning" => ["post-content", "content-warning"],
			"raw-body" => ["post-content", "raw-body"],
			"body" => ["post-content", "body"],
			"rendered-hash" => ["post-content", "rendered-hash"],
			"rendered-html" => ["post-content", "rendered-html"],
			"language" => ["post-content", "language"],
			"plink" => ["post-content", "plink"],
			"location" => ["post-content", "location"],
			"coord" => ["post-content", "coord"],
			"app" => ["post-content", "app"],
			"object-type" => ["post-content", "object-type"],
			"object" => ["post-content", "object"],
			"target-type" => ["post-content", "target-type"],
			"target" => ["post-content", "target"],
			"resource-id" => ["post-content", "resource-id"],
			"contact-id" => ["post-thread-user", "contact-id"],
			"contact-uri-id" => ["contact", "uri-id"],
			"contact-link" => ["contact", "url"],
			"contact-addr" => ["contact", "addr"],
			"contact-name" => ["contact", "name"],
			"contact-nick" => ["contact", "nick"],
			"contact-avatar" => ["contact", "thumb"],
			"contact-network" => ["contact", "network"],
			"contact-blocked" => ["contact", "blocked"],
			"contact-hidden" => ["contact", "hidden"],
			"contact-readonly" => ["contact", "readonly"],
			"contact-archive" => ["contact", "archive"],
			"contact-pending" => ["contact", "pending"],
			"contact-rel" => ["contact", "rel"],
			"contact-uid" => ["contact", "uid"],
			"contact-contact-type" => ["contact", "contact-type"],
			"writable" => "IF (`post-user`.`network` IN ('apub', 'dfrn', 'dspr', 'stat'), true, `contact`.`writable`)",
			"self" => ["contact", "self"],
			"cid" => ["contact", "id"],
			"alias" => ["contact", "alias"],
			"photo" => ["contact", "photo"],
			"name-date" => ["contact", "name-date"],
			"uri-date" => ["contact", "uri-date"],
			"avatar-date" => ["contact", "avatar-date"],
			"thumb" => ["contact", "thumb"],
			"author-id" => ["post-thread-user", "author-id"],
			"author-uri-id" => ["author", "uri-id"],
			"author-link" => ["author", "url"],
			"author-addr" => ["author", "addr"],
			"author-name" => "IF (`contact`.`url` = `author`.`url` AND `contact`.`name` != '', `contact`.`name`, `author`.`name`)",
			"author-nick" => ["author", "nick"],
			"author-avatar" => "IF (`contact`.`url` = `author`.`url` AND `contact`.`thumb` != '', `contact`.`thumb`, `author`.`thumb`)",
			"author-network" => ["author", "network"],
			"author-blocked" => ["author", "blocked"],
			"author-hidden" => ["author", "hidden"],
			"author-updated" => ["author", "updated"],
			"author-gsid" => ["author", "gsid"],
			"author-uri-id" => ["author", "uri-id"],
			"owner-id" => ["post-thread-user", "owner-id"],
			"owner-uri-id" => ["owner", "uri-id"],
			"owner-link" => ["owner", "url"],
			"owner-addr" => ["owner", "addr"],
			"owner-name" => "IF (`contact`.`url` = `owner`.`url` AND `contact`.`name` != '', `contact`.`name`, `owner`.`name`)",
			"owner-nick" => ["owner", "nick"],
			"owner-avatar" => "IF (`contact`.`url` = `owner`.`url` AND `contact`.`thumb` != '', `contact`.`thumb`, `owner`.`thumb`)",
			"owner-network" => ["owner", "network"],
			"owner-blocked" => ["owner", "blocked"],
			"owner-hidden" => ["owner", "hidden"],
			"owner-updated" => ["owner", "updated"],
			"owner-contact-type" => ["owner", "contact-type"],
			"causer-id" => ["post-thread-user", "causer-id"],
			"causer-uri-id" => ["causer", "uri-id"],
			"causer-link" => ["causer", "url"],
			"causer-addr" => ["causer", "addr"],
			"causer-name" => ["causer", "name"],
			"causer-nick" => ["causer", "nick"],
			"causer-avatar" => ["causer", "thumb"],
			"causer-network" => ["causer", "network"],
			"causer-blocked" => ["causer", "blocked"],
			"causer-hidden" => ["causer", "hidden"],
			"causer-contact-type" => ["causer", "contact-type"],
			"postopts" => ["post-delivery-data", "postopts"],
			"inform" => ["post-delivery-data", "inform"],
			"delivery_queue_count" => ["post-delivery-data", "queue_count"],
			"delivery_queue_done" => ["post-delivery-data", "queue_done"],
			"delivery_queue_failed" => ["post-delivery-data", "queue_failed"],
			"allow_cid" => "IF (`post-thread-user`.`psid` IS NULL, '', `permissionset`.`allow_cid`)",
			"allow_gid" => "IF (`post-thread-user`.`psid` IS NULL, '', `permissionset`.`allow_gid`)",
			"deny_cid" => "IF (`post-thread-user`.`psid` IS NULL, '', `permissionset`.`deny_cid`)",
			"deny_gid" => "IF (`post-thread-user`.`psid` IS NULL, '', `permissionset`.`deny_gid`)",
			"event-id" => ["post-user", "event-id"],
			"event-created" => ["event", "created"],
			"event-edited" => ["event", "edited"],
			"event-start" => ["event", "start"],
			"event-finish" => ["event", "finish"],
			"event-summary" => ["event", "summary"],
			"event-desc" => ["event", "desc"],
			"event-location" => ["event", "location"],
			"event-type" => ["event", "type"],
			"event-nofinish" => ["event", "nofinish"],
			"event-ignore" => ["event", "ignore"],
			"question-id" => ["post-question", "id"],
			"question-multiple" => ["post-question", "multiple"],
			"question-voters" => ["post-question", "voters"],
			"question-end-time" => ["post-question", "end-time"],
			"has-categories" => "EXISTS(SELECT `uri-id` FROM `post-category` WHERE `post-category`.`uri-id` = `post-thread-user`.`uri-id` AND `post-category`.`uid` = `post-thread-user`.`uid`)",
			"has-media" => "EXISTS(SELECT `id` FROM `post-media` WHERE `post-media`.`uri-id` = `post-thread-user`.`uri-id`)",
			"signed_text" => ["diaspora-interaction", "interaction"],
			"parent-guid" => ["parent-item-uri", "guid"],
			"parent-network" => ["parent-post", "network"],
			"parent-author-id" => ["parent-post", "author-id"],
			"parent-author-link" => ["parent-post-author", "url"],
			"parent-author-name" => ["parent-post-author", "name"],
			"parent-author-network" => ["parent-post-author", "network"],
			"parent-author-blocked" => ["parent-post-author", "blocked"],
			"parent-author-hidden" => ["parent-post-author", "hidden"],
		],
		"query" => "FROM `post-thread-user`
			INNER JOIN `post-user` ON `post-user`.`id` = `post-thread-user`.`post-user-id`
			STRAIGHT_JOIN `contact` ON `contact`.`id` = `post-thread-user`.`contact-id`
			STRAIGHT_JOIN `contact` AS `author` ON `author`.`id` = `post-thread-user`.`author-id`
			STRAIGHT_JOIN `contact` AS `owner` ON `owner`.`id` = `post-thread-user`.`owner-id`
			LEFT JOIN `contact` AS `causer` ON `causer`.`id` = `post-thread-user`.`causer-id`
			LEFT JOIN `item-uri` ON `item-uri`.`id` = `post-thread-user`.`uri-id`
			LEFT JOIN `item-uri` AS `thr-parent-item-uri` ON `thr-parent-item-uri`.`id` = `post-user`.`thr-parent-id`
			LEFT JOIN `item-uri` AS `parent-item-uri` ON `parent-item-uri`.`id` = `post-user`.`parent-uri-id`
			LEFT JOIN `item-uri` AS `conversation-item-uri` ON `conversation-item-uri`.`id` = `post-thread-user`.`conversation-id`
			LEFT JOIN `item-uri` AS `external-item-uri` ON `external-item-uri`.`id` = `post-user`.`external-id`
			LEFT JOIN `verb` ON `verb`.`id` = `post-user`.`vid`
			LEFT JOIN `event` ON `event`.`id` = `post-user`.`event-id`
			LEFT JOIN `diaspora-interaction` ON `diaspora-interaction`.`uri-id` = `post-thread-user`.`uri-id`
			LEFT JOIN `post-content` ON `post-content`.`uri-id` = `post-thread-user`.`uri-id`
			LEFT JOIN `item-uri` AS `quote-item-uri` ON `quote-item-uri`.`id` = `post-content`.`quote-uri-id`
			LEFT JOIN `post-delivery-data` ON `post-delivery-data`.`uri-id` = `post-thread-user`.`uri-id` AND `post-thread-user`.`origin`
			LEFT JOIN `post-question` ON `post-question`.`uri-id` = `post-thread-user`.`uri-id`
			LEFT JOIN `permissionset` ON `permissionset`.`id` = `post-thread-user`.`psid`
			LEFT JOIN `post-user` AS `parent-post` ON `parent-post`.`uri-id` = `post-user`.`parent-uri-id` AND `parent-post`.`uid` = `post-thread-user`.`uid`
			LEFT JOIN `contact` AS `parent-post-author` ON `parent-post-author`.`id` = `parent-post`.`author-id`"
	],
	"post-view" => [
		"fields" => [
			"uri" => ["item-uri", "uri"],
			"uri-id" => ["post", "uri-id"],
			"parent-uri" => ["parent-item-uri", "uri"],
			"parent-uri-id" => ["post", "parent-uri-id"],
			"thr-parent" => ["thr-parent-item-uri", "uri"],
			"thr-parent-id" => ["post", "thr-parent-id"],
			"conversation" => ["conversation-item-uri", "uri"],
			"conversation-id" => ["post-thread", "conversation-id"],
			"quote-uri" => ["quote-item-uri", "uri"],
			"quote-uri-id" => ["post-content", "quote-uri-id"],
			"guid" => ["item-uri", "guid"],
			"gravity" => ["post", "gravity"],
			"extid" => ["external-item-uri", "uri"],
			"external-id" => ["post", "external-id"],
			"created" => ["post", "created"],
			"edited" => ["post", "edited"],
			"commented" => ["post-thread", "commented"],
			"received" => ["post", "received"],
			"changed" => ["post-thread", "changed"],
			"post-type" => ["post", "post-type"],
			"private" => ["post", "private"],
			"visible" => ["post", "visible"],
			"deleted" => ["post", "deleted"],
			"global" => ["post", "global"],
			"featured" => "EXISTS(SELECT `type` FROM `post-collection` WHERE `type` = 0 AND `uri-id` = `post`.`uri-id`)",
			"network" => ["post", "network"],
			"vid" => ["post", "vid"],
			"verb" => "IF (`post`.`vid` IS NULL, '', `verb`.`name`)",
			"title" => ["post-content", "title"],
			"content-warning" => ["post-content", "content-warning"],
			"raw-body" => ["post-content", "raw-body"],
			"body" => ["post-content", "body"],
			"rendered-hash" => ["post-content", "rendered-hash"],
			"rendered-html" => ["post-content", "rendered-html"],
			"language" => ["post-content", "language"],
			"plink" => ["post-content", "plink"],
			"location" => ["post-content", "location"],
			"coord" => ["post-content", "coord"],
			"app" => ["post-content", "app"],
			"object-type" => ["post-content", "object-type"],
			"object" => ["post-content", "object"],
			"target-type" => ["post-content", "target-type"],
			"target" => ["post-content", "target"],
			"resource-id" => ["post-content", "resource-id"],
			"contact-id" => ["post", "author-id"],
			"contact-uri-id" => ["author", "uri-id"],
			"contact-link" => ["author", "url"],
			"contact-addr" => ["author", "addr"],
			"contact-name" => ["author", "name"],
			"contact-nick" => ["author", "nick"],
			"contact-avatar" => ["author", "thumb"],
			"contact-network" => ["author", "network"],
			"contact-blocked" => ["author", "blocked"],
			"contact-hidden" => ["author", "hidden"],
			"contact-readonly" => ["author", "readonly"],
			"contact-archive" => ["author", "archive"],
			"contact-pending" => ["author", "pending"],
			"contact-rel" => ["author", "rel"],
			"contact-uid" => ["author", "uid"],
			"contact-contact-type" => ["author", "contact-type"],
			"writable" => "IF (`post`.`network` IN ('apub', 'dfrn', 'dspr', 'stat'), true, `author`.`writable`)",
			"self" => "false",
			"cid" => ["author", "id"],
			"alias" => ["author", "alias"],
			"photo" => ["author", "photo"],
			"name-date" => ["author", "name-date"],
			"uri-date" => ["author", "uri-date"],
			"avatar-date" => ["author", "avatar-date"],
			"thumb" => ["author", "thumb"],
			"author-id" => ["post", "author-id"],
			"author-uri-id" => ["author", "uri-id"],
			"author-link" => ["author", "url"],
			"author-addr" => ["author", "addr"],
			"author-name" => ["author", "name"],
			"author-nick" => ["author", "nick"],
			"author-avatar" => ["author", "thumb"],
			"author-network" => ["author", "network"],
			"author-blocked" => ["author", "blocked"],
			"author-hidden" => ["author", "hidden"],
			"author-updated" => ["author", "updated"],
			"author-gsid" => ["author", "gsid"],
			"author-uri-id" => ["author", "uri-id"],
			"owner-id" => ["post", "owner-id"],
			"owner-uri-id" => ["owner", "uri-id"],
			"owner-link" => ["owner", "url"],
			"owner-addr" => ["owner", "addr"],
			"owner-name" => ["owner", "name"],
			"owner-nick" => ["owner", "nick"],
			"owner-avatar" => ["owner", "thumb"],
			"owner-network" => ["owner", "network"],
			"owner-blocked" => ["owner", "blocked"],
			"owner-hidden" => ["owner", "hidden"],
			"owner-updated" => ["owner", "updated"],
			"owner-contact-type" => ["owner", "contact-type"],
			"causer-id" => ["post", "causer-id"],
			"causer-uri-id" => ["causer", "uri-id"],
			"causer-link" => ["causer", "url"],
			"causer-addr" => ["causer", "addr"],
			"causer-name" => ["causer", "name"],
			"causer-nick" => ["causer", "nick"],
			"causer-avatar" => ["causer", "thumb"],
			"causer-network" => ["causer", "network"],
			"causer-blocked" => ["causer", "blocked"],
			"causer-hidden" => ["causer", "hidden"],
			"causer-contact-type" => ["causer", "contact-type"],
			"question-id" => ["post-question", "id"],
			"question-multiple" => ["post-question", "multiple"],
			"question-voters" => ["post-question", "voters"],
			"question-end-time" => ["post-question", "end-time"],
			"has-categories" => "0",
			"has-media" => "EXISTS(SELECT `id` FROM `post-media` WHERE `post-media`.`uri-id` = `post`.`uri-id`)",
			"signed_text" => ["diaspora-interaction", "interaction"],
			"parent-guid" => ["parent-item-uri", "guid"],
			"parent-network" => ["parent-post", "network"],
			"parent-author-id" => ["parent-post", "author-id"],
			"parent-author-link" => ["parent-post-author", "url"],
			"parent-author-name" => ["parent-post-author", "name"],
			"parent-author-network" => ["parent-post-author", "network"],
			"parent-author-blocked" => ["parent-post-author", "blocked"],
			"parent-author-hidden" => ["parent-post-author", "hidden"],
		],
		"query" => "FROM `post`
			STRAIGHT_JOIN `post-thread` ON `post-thread`.`uri-id` = `post`.`parent-uri-id`
			STRAIGHT_JOIN `contact` AS `author` ON `author`.`id` = `post`.`author-id`
			STRAIGHT_JOIN `contact` AS `owner` ON `owner`.`id` = `post`.`owner-id`
			LEFT JOIN `contact` AS `causer` ON `causer`.`id` = `post`.`causer-id`
			LEFT JOIN `item-uri` ON `item-uri`.`id` = `post`.`uri-id`
			LEFT JOIN `item-uri` AS `thr-parent-item-uri` ON `thr-parent-item-uri`.`id` = `post`.`thr-parent-id`
			LEFT JOIN `item-uri` AS `parent-item-uri` ON `parent-item-uri`.`id` = `post`.`parent-uri-id`
			LEFT JOIN `item-uri` AS `conversation-item-uri` ON `conversation-item-uri`.`id` = `post-thread`.`conversation-id`
			LEFT JOIN `item-uri` AS `external-item-uri` ON `external-item-uri`.`id` = `post`.`external-id`
			LEFT JOIN `verb` ON `verb`.`id` = `post`.`vid`
			LEFT JOIN `diaspora-interaction` ON `diaspora-interaction`.`uri-id` = `post`.`uri-id`
			LEFT JOIN `post-content` ON `post-content`.`uri-id` = `post`.`uri-id`
			LEFT JOIN `item-uri` AS `quote-item-uri` ON `quote-item-uri`.`id` = `post-content`.`quote-uri-id`
			LEFT JOIN `post-question` ON `post-question`.`uri-id` = `post`.`uri-id`
			LEFT JOIN `post` AS `parent-post` ON `parent-post`.`uri-id` = `post`.`parent-uri-id`
			LEFT JOIN `contact` AS `parent-post-author` ON `parent-post-author`.`id` = `parent-post`.`author-id`"
	],
	"post-thread-view" => [
		"fields" => [
			"uri" => ["item-uri", "uri"],
			"uri-id" => ["post-thread", "uri-id"],
			"parent-uri" => ["parent-item-uri", "uri"],
			"parent-uri-id" => ["post", "parent-uri-id"],
			"thr-parent" => ["thr-parent-item-uri", "uri"],
			"thr-parent-id" => ["post", "thr-parent-id"],
			"conversation" => ["conversation-item-uri", "uri"],
			"conversation-id" => ["post-thread", "conversation-id"],
			"quote-uri" => ["quote-item-uri", "uri"],
			"quote-uri-id" => ["post-content", "quote-uri-id"],
			"guid" => ["item-uri", "guid"],
			"gravity" => ["post", "gravity"],
			"extid" => ["external-item-uri", "uri"],
			"external-id" => ["post", "external-id"],
			"created" => ["post-thread", "created"],
			"edited" => ["post", "edited"],
			"commented" => ["post-thread", "commented"],
			"received" => ["post-thread", "received"],
			"changed" => ["post-thread", "changed"],
			"post-type" => ["post", "post-type"],
			"private" => ["post", "private"],
			"visible" => ["post", "visible"],
			"deleted" => ["post", "deleted"],
			"global" => ["post", "global"],
			"featured" => "EXISTS(SELECT `type` FROM `post-collection` WHERE `type` = 0 AND `uri-id` = `post-thread`.`uri-id`)",
			"network" => ["post-thread", "network"],
			"vid" => ["post", "vid"],
			"verb" => "IF (`post`.`vid` IS NULL, '', `verb`.`name`)",
			"title" => ["post-content", "title"],
			"content-warning" => ["post-content", "content-warning"],
			"raw-body" => ["post-content", "raw-body"],
			"body" => ["post-content", "body"],
			"rendered-hash" => ["post-content", "rendered-hash"],
			"rendered-html" => ["post-content", "rendered-html"],
			"language" => ["post-content", "language"],
			"plink" => ["post-content", "plink"],
			"location" => ["post-content", "location"],
			"coord" => ["post-content", "coord"],
			"app" => ["post-content", "app"],
			"object-type" => ["post-content", "object-type"],
			"object" => ["post-content", "object"],
			"target-type" => ["post-content", "target-type"],
			"target" => ["post-content", "target"],
			"resource-id" => ["post-content", "resource-id"],
			"contact-id" => ["post-thread", "author-id"],
			"contact-uri-id" => ["author", "uri-id"],
			"contact-link" => ["author", "url"],
			"contact-addr" => ["author", "addr"],
			"contact-name" => ["author", "name"],
			"contact-nick" => ["author", "nick"],
			"contact-avatar" => ["author", "thumb"],
			"contact-network" => ["author", "network"],
			"contact-blocked" => ["author", "blocked"],
			"contact-hidden" => ["author", "hidden"],
			"contact-readonly" => ["author", "readonly"],
			"contact-archive" => ["author", "archive"],
			"contact-pending" => ["author", "pending"],
			"contact-rel" => ["author", "rel"],
			"contact-uid" => ["author", "uid"],
			"contact-contact-type" => ["author", "contact-type"],
			"writable" => "IF (`post`.`network` IN ('apub', 'dfrn', 'dspr', 'stat'), true, `author`.`writable`)",
			"self" => "false",
			"cid" => ["author", "id"],
			"alias" => ["author", "alias"],
			"photo" => ["author", "photo"],
			"name-date" => ["author", "name-date"],
			"uri-date" => ["author", "uri-date"],
			"avatar-date" => ["author", "avatar-date"],
			"thumb" => ["author", "thumb"],
			"author-id" => ["post-thread", "author-id"],
			"author-uri-id" => ["author", "uri-id"],
			"author-link" => ["author", "url"],
			"author-addr" => ["author", "addr"],
			"author-name" => ["author", "name"],
			"author-nick" => ["author", "nick"],
			"author-avatar" => ["author", "thumb"],
			"author-network" => ["author", "network"],
			"author-blocked" => ["author", "blocked"],
			"author-hidden" => ["author", "hidden"],
			"author-updated" => ["author", "updated"],
			"author-gsid" => ["author", "gsid"],
			"author-uri-id" => ["author", "uri-id"],
			"owner-id" => ["post-thread", "owner-id"],
			"owner-uri-id" => ["owner", "uri-id"],
			"owner-link" => ["owner", "url"],
			"owner-addr" => ["owner", "addr"],
			"owner-name" => ["owner", "name"],
			"owner-nick" => ["owner", "nick"],
			"owner-avatar" => ["owner", "thumb"],
			"owner-network" => ["owner", "network"],
			"owner-blocked" => ["owner", "blocked"],
			"owner-hidden" => ["owner", "hidden"],
			"owner-updated" => ["owner", "updated"],
			"owner-contact-type" => ["owner", "contact-type"],
			"causer-id" => ["post-thread", "causer-id"],
			"causer-uri-id" => ["causer", "uri-id"],
			"causer-link" => ["causer", "url"],
			"causer-addr" => ["causer", "addr"],
			"causer-name" => ["causer", "name"],
			"causer-nick" => ["causer", "nick"],
			"causer-avatar" => ["causer", "thumb"],
			"causer-network" => ["causer", "network"],
			"causer-blocked" => ["causer", "blocked"],
			"causer-hidden" => ["causer", "hidden"],
			"causer-contact-type" => ["causer", "contact-type"],
			"question-id" => ["post-question", "id"],
			"question-multiple" => ["post-question", "multiple"],
			"question-voters" => ["post-question", "voters"],
			"question-end-time" => ["post-question", "end-time"],
			"has-categories" => "0",
			"has-media" => "EXISTS(SELECT `id` FROM `post-media` WHERE `post-media`.`uri-id` = `post-thread`.`uri-id`)",
			"signed_text" => ["diaspora-interaction", "interaction"],
			"parent-guid" => ["parent-item-uri", "guid"],
			"parent-network" => ["parent-post", "network"],
			"parent-author-id" => ["parent-post", "author-id"],
			"parent-author-link" => ["parent-post-author", "url"],
			"parent-author-name" => ["parent-post-author", "name"],
			"parent-author-network" => ["parent-post-author", "network"],
			"parent-author-blocked" => ["parent-post-author", "blocked"],
			"parent-author-hidden" => ["parent-post-author", "hidden"],
		],
		"query" => "FROM `post-thread`
			INNER JOIN `post` ON `post`.`uri-id` = `post-thread`.`uri-id`
			STRAIGHT_JOIN `contact` AS `author` ON `author`.`id` = `post-thread`.`author-id`
			STRAIGHT_JOIN `contact` AS `owner` ON `owner`.`id` = `post-thread`.`owner-id`
			LEFT JOIN `contact` AS `causer` ON `causer`.`id` = `post-thread`.`causer-id`
			LEFT JOIN `item-uri` ON `item-uri`.`id` = `post-thread`.`uri-id`
			LEFT JOIN `item-uri` AS `thr-parent-item-uri` ON `thr-parent-item-uri`.`id` = `post`.`thr-parent-id`
			LEFT JOIN `item-uri` AS `parent-item-uri` ON `parent-item-uri`.`id` = `post`.`parent-uri-id`
			LEFT JOIN `item-uri` AS `conversation-item-uri` ON `conversation-item-uri`.`id` = `post-thread`.`conversation-id`
			LEFT JOIN `item-uri` AS `external-item-uri` ON `external-item-uri`.`id` = `post`.`external-id`
			LEFT JOIN `verb` ON `verb`.`id` = `post`.`vid`
			LEFT JOIN `diaspora-interaction` ON `diaspora-interaction`.`uri-id` = `post-thread`.`uri-id`
			LEFT JOIN `post-content` ON `post-content`.`uri-id` = `post-thread`.`uri-id`
			LEFT JOIN `item-uri` AS `quote-item-uri` ON `quote-item-uri`.`id` = `post-content`.`quote-uri-id`
			LEFT JOIN `post-question` ON `post-question`.`uri-id` = `post-thread`.`uri-id`
			LEFT JOIN `post` AS `parent-post` ON `parent-post`.`uri-id` = `post`.`parent-uri-id`
			LEFT JOIN `contact` AS `parent-post-author` ON `parent-post-author`.`id` = `parent-post`.`author-id`"
	],
	"category-view" => [
		"fields" => [
			"uri-id" => ["post-category", "uri-id"],
			"uid" => ["post-category", "uid"],
			"type" => ["post-category", "type"],
			"tid" => ["post-category", "tid"],
			"name" => ["tag", "name"],
			"url" => ["tag", "url"],
		],
		"query" => "FROM `post-category`
			LEFT JOIN `tag` ON `post-category`.`tid` = `tag`.`id`"
	],
	"collection-view" => [
		"fields" => [
			"uri-id" => ["post-collection", "uri-id"],
			"type" => ["post-collection", "type"],
			"cid" => ["post-collection", "author-id"],
			"received" => ["post", "received"],
			"created" => ["post", "created"],
			"commented" => ["post-thread", "commented"],
			"private" => ["post", "private"],
			"visible" => ["post", "visible"],
			"deleted" => ["post", "deleted"],
			"thr-parent-id" => ["post", "thr-parent-id"],
			"author-id" => ["post-collection", "author-id"],
			"gravity" => ["post", "gravity"],
		],
		"query" => "FROM `post-collection`
			INNER JOIN `post` ON `post-collection`.`uri-id` = `post`.`uri-id`
			INNER JOIN `post-thread` ON `post-thread`.`uri-id` = `post`.`parent-uri-id`"
	],
	"tag-view" => [
		"fields" => [
			"uri-id" => ["post-tag", "uri-id"],
			"type" => ["post-tag", "type"],
			"tid" => ["post-tag", "tid"],
			"cid" => ["post-tag", "cid"],
			"name" => "CASE `cid` WHEN 0 THEN `tag`.`name` ELSE `contact`.`name` END",
			"url" => "CASE `cid` WHEN 0 THEN `tag`.`url` ELSE `contact`.`url` END",
			"tag-type" => "CASE `cid` WHEN 0 THEN `tag`.`type` ELSE 1 END",
		],
		"query" => "FROM `post-tag`
			LEFT JOIN `tag` ON `post-tag`.`tid` = `tag`.`id`
			LEFT JOIN `contact` ON `post-tag`.`cid` = `contact`.`id`"
	],
	"network-item-view" => [
		"fields" => [
			"uri-id" => ["post-user", "uri-id"],
			"parent" => ["parent-post", "id"],
			"received" => ["post-user", "received"],
			"commented" => ["post-thread-user", "commented"],
			"created" => ["post-user", "created"],
			"uid" => ["post-user", "uid"],
			"starred" => ["post-thread-user", "starred"],
			"mention" => ["post-thread-user", "mention"],
			"network" => ["post-user", "network"],
			"unseen" => ["post-user", "unseen"],
			"gravity" => ["post-user", "gravity"],
			"contact-id" => ["post-user", "contact-id"],
			"contact-type" => ["ownercontact", "contact-type"],
		],
		"query" => "FROM `post-user`
			STRAIGHT_JOIN `post-thread-user` ON `post-thread-user`.`uri-id` = `post-user`.`parent-uri-id` AND `post-thread-user`.`uid` = `post-user`.`uid`			
			INNER JOIN `contact` ON `contact`.`id` = `post-thread-user`.`contact-id`
			LEFT JOIN `user-contact` AS `author` ON `author`.`uid` = `post-thread-user`.`uid` AND `author`.`cid` = `post-thread-user`.`author-id`
			LEFT JOIN `user-contact` AS `owner` ON `owner`.`uid` = `post-thread-user`.`uid` AND `owner`.`cid` = `post-thread-user`.`owner-id`
			INNER JOIN `contact` AS `ownercontact` ON `ownercontact`.`id` = `post-thread-user`.`owner-id`
			LEFT JOIN `post-user` AS `parent-post` ON `parent-post`.`uri-id` = `post-user`.`parent-uri-id` AND `parent-post`.`uid` = `post-user`.`uid`
			WHERE `post-user`.`visible` AND NOT `post-user`.`deleted`
			AND (NOT `contact`.`readonly` AND NOT `contact`.`blocked` AND NOT `contact`.`pending`)
			AND (`post-user`.`hidden` IS NULL OR NOT `post-user`.`hidden`)
			AND (`author`.`blocked` IS NULL OR NOT `author`.`blocked`)
			AND (`owner`.`blocked` IS NULL OR NOT `owner`.`blocked`)"
	],
	"network-thread-view" => [
		"fields" => [
			"uri-id" => ["post-thread-user", "uri-id"],
			"parent" => ["parent-post", "id"],
			"received" => ["post-thread-user", "received"],
			"commented" => ["post-thread-user", "commented"],
			"created" => ["post-thread-user", "created"],
			"uid" => ["post-thread-user", "uid"],
			"starred" => ["post-thread-user", "starred"],
			"mention" => ["post-thread-user", "mention"],
			"network" => ["post-thread-user", "network"],
			"contact-id" => ["post-thread-user", "contact-id"],
			"contact-type" => ["ownercontact", "contact-type"],
		],
		"query" => "FROM `post-thread-user`
			INNER JOIN `post-user` ON `post-user`.`id` = `post-thread-user`.`post-user-id`
			STRAIGHT_JOIN `contact` ON `contact`.`id` = `post-thread-user`.`contact-id`
			LEFT JOIN `user-contact` AS `author` ON `author`.`uid` = `post-thread-user`.`uid` AND `author`.`cid` = `post-thread-user`.`author-id`
			LEFT JOIN `user-contact` AS `owner` ON `owner`.`uid` = `post-thread-user`.`uid` AND `owner`.`cid` = `post-thread-user`.`owner-id`
			LEFT JOIN `contact` AS `ownercontact` ON `ownercontact`.`id` = `post-thread-user`.`owner-id`
			LEFT JOIN `post-user` AS `parent-post` ON `parent-post`.`uri-id` = `post-user`.`parent-uri-id` AND `parent-post`.`uid` = `post-user`.`uid`
			WHERE `post-user`.`visible` AND NOT `post-user`.`deleted`
			AND (NOT `contact`.`readonly` AND NOT `contact`.`blocked` AND NOT `contact`.`pending`)
			AND (`post-thread-user`.`hidden` IS NULL OR NOT `post-thread-user`.`hidden`)
			AND (`author`.`blocked` IS NULL OR NOT `author`.`blocked`)
			AND (`owner`.`blocked` IS NULL OR NOT `owner`.`blocked`)"
	],
	"owner-view" => [
		"fields" => [
			"id" => ["contact", "id"],
			"uid" => ["contact", "uid"],
			"created" => ["contact", "created"],
			"updated" => ["contact", "updated"],
			"self" => ["contact", "self"],
			"remote_self" => ["contact", "remote_self"],
			"rel" => ["contact", "rel"],
			"network" => ["contact", "network"],
			"protocol" => ["contact", "protocol"],
			"name" => ["contact", "name"],
			"nick" => ["contact", "nick"],
			"location" => ["contact", "location"],
			"about" => ["contact", "about"],
			"keywords" => ["contact", "keywords"],
			"xmpp" => ["contact", "xmpp"],
			"matrix" => ["contact", "matrix"],
			"attag" => ["contact", "attag"],
			"avatar" => ["contact", "avatar"],
			"photo" => ["contact", "photo"],
			"thumb" => ["contact", "thumb"],
			"micro" => ["contact", "micro"],
			"header" => ["contact", "header"],
			"url" => ["contact", "url"],
			"nurl" => ["contact", "nurl"],
			"uri-id" => ["contact", "uri-id"],
			"addr" => ["contact", "addr"],
			"alias" => ["contact", "alias"],
			"pubkey" => ["contact", "pubkey"],
			"prvkey" => ["contact", "prvkey"],
			"batch" => ["contact", "batch"],
			"request" => ["contact", "request"],
			"notify" => ["contact", "notify"],
			"poll" => ["contact", "poll"],
			"confirm" => ["contact", "confirm"],
			"poco" => ["contact", "poco"],
			"subhub" => ["contact", "subhub"],
			"hub-verify" => ["contact", "hub-verify"],
			"last-update" => ["contact", "last-update"],
			"success_update" => ["contact", "success_update"],
			"failure_update" => ["contact", "failure_update"],
			"name-date" => ["contact", "name-date"],
			"uri-date" => ["contact", "uri-date"],
			"avatar-date" => ["contact", "avatar-date"],
			"picdate" => ["contact", "avatar-date"], /// @todo Replaces all uses of "picdate" with "avatar-date"
			"term-date" => ["contact", "term-date"],
			"last-item" => ["contact", "last-item"],
			"priority" => ["contact", "priority"],
			"blocked" => ["user", "blocked"],
			"block_reason" => ["contact", "block_reason"],
			"readonly" => ["contact", "readonly"],
			"writable" => ["contact", "writable"],
			"forum" => ["contact", "forum"],
			"prv" => ["contact", "prv"],
			"contact-type" => ["contact", "contact-type"],
			"manually-approve" => ["contact", "manually-approve"],
			"hidden" => ["contact", "hidden"],
			"archive" => ["contact", "archive"],
			"pending" => ["contact", "pending"],
			"deleted" => ["contact", "deleted"],
			"unsearchable" => ["contact", "unsearchable"],
			"sensitive" => ["contact", "sensitive"],
			"baseurl" => ["contact", "baseurl"],
			"reason" => ["contact", "reason"],
			"info" => ["contact", "info"],
			"bdyear" => ["contact", "bdyear"],
			"bd" => ["contact", "bd"],
			"notify_new_posts" => ["contact", "notify_new_posts"],
			"fetch_further_information" => ["contact", "fetch_further_information"],
			"ffi_keyword_denylist" => ["contact", "ffi_keyword_denylist"],
			"parent-uid" => ["user", "parent-uid"],
			"guid" => ["user", "guid"],
			"nickname" => ["user", "nickname"], /// @todo Replaces all uses of "nickname" with "nick"
			"email" => ["user", "email"],
			"openid" => ["user", "openid"],
			"timezone" => ["user", "timezone"],
			"language" => ["user", "language"],
			"register_date" => ["user", "register_date"],
			"login_date" => ["user", "login_date"],
			"default-location" => ["user", "default-location"],
			"allow_location" => ["user", "allow_location"],
			"theme" => ["user", "theme"],
			"upubkey" => ["user", "pubkey"],
			"uprvkey" => ["user", "prvkey"],
			"sprvkey" => ["user", "sprvkey"],
			"spubkey" => ["user", "spubkey"],
			"verified" => ["user", "verified"],
			"blockwall" => ["user", "blockwall"],
			"hidewall" => ["user", "hidewall"],
			"blocktags" => ["user", "blocktags"],
			"unkmail" => ["user", "unkmail"],
			"cntunkmail" => ["user", "cntunkmail"],
			"notify-flags" => ["user", "notify-flags"],
			"page-flags" => ["user", "page-flags"],
			"account-type" => ["user", "account-type"],
			"prvnets" => ["user", "prvnets"],
			"maxreq" => ["user", "maxreq"],
			"expire" => ["user", "expire"],
			"account_removed" => ["user", "account_removed"],
			"account_expired" => ["user", "account_expired"],
			"account_expires_on" => ["user", "account_expires_on"],
			"expire_notification_sent" => ["user", "expire_notification_sent"],
			"def_gid" => ["user", "def_gid"],
			"allow_cid" => ["user", "allow_cid"],
			"allow_gid" => ["user", "allow_gid"],
			"deny_cid" => ["user", "deny_cid"],
			"deny_gid" => ["user", "deny_gid"],
			"openidserver" => ["user", "openidserver"],
			"publish" => ["profile", "publish"],
			"net-publish" => ["profile", "net-publish"],
			"hide-friends" => ["profile", "hide-friends"],
			"prv_keywords" => ["profile", "prv_keywords"],
			"pub_keywords" => ["profile", "pub_keywords"],
			"address" => ["profile", "address"],
			"locality" => ["profile", "locality"],
			"region" => ["profile", "region"],
			"postal-code" => ["profile", "postal-code"],
			"country-name" => ["profile", "country-name"],
			"homepage" => ["profile", "homepage"],
			"dob" => ["profile", "dob"],
		],
		"query" => "FROM `user`
			INNER JOIN `contact` ON `contact`.`uid` = `user`.`uid` AND `contact`.`self`
			INNER JOIN `profile` ON `profile`.`uid` = `user`.`uid`"
	],
	"account-view" => [
		"fields" => [
			"id" => ["contact", "id"],
			"url" => ["contact", "url"],
			"nurl" => ["contact", "nurl"],
			"uri-id" => ["contact", "uri-id"],
			"guid" => ["item-uri", "guid"],
			"addr" => ["contact", "addr"],
			"alias" => ["contact", "alias"],
			"name" => ["contact", "name"],
			"nick" => ["contact", "nick"],
			"about" => ["contact", "about"],
			"keywords" => ["contact", "keywords"],
			"xmpp" => ["contact", "xmpp"],
			"matrix" => ["contact", "matrix"],
			"avatar" => ["contact", "avatar"],
			"photo" => ["contact", "photo"],
			"thumb" => ["contact", "thumb"],
			"micro" => ["contact", "micro"],
			"header" => ["contact", "header"],
			"created" => ["contact", "created"],
			"updated" => ["contact", "updated"],
			"network" => ["contact", "network"],
			"protocol" => ["contact", "protocol"],
			"location" => ["contact", "location"],
			"attag" => ["contact", "attag"],
			"pubkey" => ["contact", "pubkey"],
			"prvkey" => ["contact", "prvkey"],
			"subscribe" => ["contact", "subscribe"],
			"last-update" => ["contact", "last-update"],
			"success_update" => ["contact", "success_update"],
			"failure_update" => ["contact", "failure_update"],
			"failed" => ["contact", "failed"],
			"last-item" => ["contact", "last-item"],
			"last-discovery" => ["contact", "last-discovery"],
			"contact-type" => ["contact", "contact-type"],
			"manually-approve" => ["contact", "manually-approve"],
			"unsearchable" => ["contact", "unsearchable"],
			"sensitive" => ["contact", "sensitive"],
			"baseurl" => ["contact", "baseurl"],
			"gsid" => ["contact", "gsid"],
			"info" => ["contact", "info"],
			"bdyear" => ["contact", "bdyear"],
			"bd" => ["contact", "bd"],
			"poco" => ["contact", "poco"],
			"name-date" => ["contact", "name-date"],
			"uri-date" => ["contact", "uri-date"],
			"avatar-date" => ["contact", "avatar-date"],
			"term-date" => ["contact", "term-date"],
			"global-ignored" => ["contact", "hidden"],
			"global-blocked" => ["contact", "blocked"],
			"hidden" => ["contact", "hidden"],
			"archive" => ["contact", "archive"],
			"deleted" => ["contact", "deleted"],
			"blocked" => ["contact", "blocked"],
			"dfrn-notify" => ["contact", "notify"],
			"dfrn-poll" => ["contact", "poll"],
			"diaspora-guid" => ["fcontact", "guid"],
			"diaspora-batch" => ["fcontact", "batch"],
			"diaspora-notify" => ["fcontact", "notify"],
			"diaspora-poll" => ["fcontact", "poll"],
			"diaspora-alias" => ["fcontact", "alias"],
			"ap-uuid" => ["apcontact", "uuid"],
			"ap-type" => ["apcontact", "type"],
			"ap-following" => ["apcontact", "following"],
			"ap-followers" => ["apcontact", "followers"],
			"ap-inbox" => ["apcontact", "inbox"],
			"ap-outbox" => ["apcontact", "outbox"],
			"ap-sharedinbox" => ["apcontact", "sharedinbox"],
			"ap-generator" => ["apcontact", "generator"],
			"ap-following_count" => ["apcontact", "following_count"],
			"ap-followers_count" => ["apcontact", "followers_count"],
			"ap-statuses_count" => ["apcontact", "statuses_count"],
			"site_name" => ["gserver", "site_name"],
			"platform" => ["gserver", "platform"],
			"version" => ["gserver", "version"],
		],
		"query" => "FROM `contact`
			LEFT JOIN `item-uri` ON `item-uri`.`id` = `contact`.`uri-id`
			LEFT JOIN `apcontact` ON `apcontact`.`uri-id` = `contact`.`uri-id`
			LEFT JOIN `fcontact` ON `fcontact`.`uri-id` = contact.`uri-id`
			LEFT JOIN `gserver` ON `gserver`.`id` = contact.`gsid`
			WHERE `contact`.`uid` = 0"			
	],
	"account-user-view" => [
		"fields" => [
			"id" => ["ucontact", "id"],
			"pid" => ["contact", "id"],
			"uid" => ["ucontact", "uid"],
			"url" => ["contact", "url"],
			"nurl" => ["contact", "nurl"],
			"uri-id" => ["contact", "uri-id"],
			"guid" => ["item-uri", "guid"],
			"addr" => ["contact", "addr"],
			"alias" => ["contact", "alias"],
			"name" => ["contact", "name"],
			"nick" => ["contact", "nick"],
			"about" => ["contact", "about"],
			"keywords" => ["contact", "keywords"],
			"xmpp" => ["contact", "xmpp"],
			"matrix" => ["contact", "matrix"],
			"avatar" => ["contact", "avatar"],
			"photo" => ["contact", "photo"],
			"thumb" => ["contact", "thumb"],
			"micro" => ["contact", "micro"],
			"header" => ["contact", "header"],
			"created" => ["contact", "created"],
			"updated" => ["contact", "updated"],
			"self" => ["ucontact", "self"],
			"remote_self" => ["ucontact", "remote_self"],
			"rel" =>  ["ucontact", "rel"],
			"network" => ["contact", "network"],
			"protocol" => ["ucontact", "protocol"],
			"location" => ["contact", "location"],
			"attag" => ["ucontact", "attag"],
			"pubkey" => ["contact", "pubkey"],
			"prvkey" => ["contact", "prvkey"],
			"subscribe" => ["contact", "subscribe"],
			"last-update" => ["contact", "last-update"],
			"success_update" => ["contact", "success_update"],
			"failure_update" => ["contact", "failure_update"],
			"failed" => ["contact", "failed"],
			"last-item" => ["contact", "last-item"],
			"last-discovery" => ["contact", "last-discovery"],
			"contact-type" => ["contact", "contact-type"],
			"manually-approve" => ["contact", "manually-approve"],
			"unsearchable" => ["contact", "unsearchable"],
			"sensitive" => ["contact", "sensitive"],
			"baseurl" => ["contact", "baseurl"],
			"gsid" => ["contact", "gsid"],
			"info" => ["ucontact", "info"],
			"bdyear" => ["contact", "bdyear"],
			"bd" => ["contact", "bd"],
			"poco" => ["contact", "poco"],
			"name-date" => ["contact", "name-date"],
			"uri-date" => ["contact", "uri-date"],
			"avatar-date" => ["contact", "avatar-date"],
			"term-date" => ["contact", "term-date"],
			"global-ignored" => ["contact", "hidden"],
			"global-blocked" => ["contact", "blocked"],
			"hidden" => ["ucontact", "hidden"],
			"archive" => ["ucontact", "archive"],
			"pending" => ["ucontact", "pending"],
			"deleted" => ["ucontact", "deleted"],
			"notify_new_posts" => ["ucontact", "notify_new_posts"],
			"fetch_further_information" => ["ucontact", "fetch_further_information"],
			"ffi_keyword_denylist" => ["ucontact", "ffi_keyword_denylist"],
			"rating" => ["ucontact", "rating"],
			"readonly" => ["ucontact", "readonly"],
			"blocked" => ["ucontact", "blocked"],
			"block_reason" => ["ucontact", "block_reason"],
			"subhub" => ["ucontact", "subhub"],
			"hub-verify" => ["ucontact", "hub-verify"],
			"reason" => ["ucontact", "reason"],
			"dfrn-notify" => ["contact", "notify"],
			"dfrn-poll" => ["contact", "poll"],
			"diaspora-guid" => ["fcontact", "guid"],
			"diaspora-batch" => ["fcontact", "batch"],
			"diaspora-notify" => ["fcontact", "notify"],
			"diaspora-poll" => ["fcontact", "poll"],
			"diaspora-alias" => ["fcontact", "alias"],
			"diaspora-interacting_count" => ["fcontact", "interacting_count"],
			"diaspora-interacted_count" => ["fcontact", "interacted_count"],
			"diaspora-post_count" => ["fcontact", "post_count"],
			"ap-uuid" => ["apcontact", "uuid"],
			"ap-type" => ["apcontact", "type"],
			"ap-following" => ["apcontact", "following"],
			"ap-followers" => ["apcontact", "followers"],
			"ap-inbox" => ["apcontact", "inbox"],
			"ap-outbox" => ["apcontact", "outbox"],
			"ap-sharedinbox" => ["apcontact", "sharedinbox"],
			"ap-generator" => ["apcontact", "generator"],
			"ap-following_count" => ["apcontact", "following_count"],
			"ap-followers_count" => ["apcontact", "followers_count"],
			"ap-statuses_count" => ["apcontact", "statuses_count"],
			"site_name" => ["gserver", "site_name"],
			"platform" => ["gserver", "platform"],
			"version" => ["gserver", "version"],
		],
		"query" => "FROM `contact` AS `ucontact`
			INNER JOIN `contact` ON `contact`.`uri-id` = `ucontact`.`uri-id` AND `contact`.`uid` = 0
			LEFT JOIN `item-uri` ON `item-uri`.`id` = `ucontact`.`uri-id`
			LEFT JOIN `apcontact` ON `apcontact`.`uri-id` = `ucontact`.`uri-id`
			LEFT JOIN `fcontact` ON `fcontact`.`uri-id` = `ucontact`.`uri-id` AND `fcontact`.`network` = 'dspr'
			LEFT JOIN `gserver` ON `gserver`.`id` = contact.`gsid`"
	],
	"pending-view" => [
		"fields" => [
			"id" => ["register", "id"],
			"hash" => ["register", "hash"],
			"created" => ["register", "created"],
			"uid" => ["register", "uid"],
			"password" => ["register", "password"],
			"language" => ["register", "language"],
			"note" => ["register", "note"],
			"self" => ["contact", "self"],
			"name" => ["contact", "name"],
			"url" => ["contact", "url"],
			"micro" => ["contact", "micro"],
			"email" => ["user", "email"],
			"nick" => ["contact", "nick"],
		],
		"query" => "FROM `register`
			INNER JOIN `contact` ON `register`.`uid` = `contact`.`uid`
			INNER JOIN `user` ON `register`.`uid` = `user`.`uid`"
	],
	"tag-search-view" => [
		"fields" => [
			"uri-id" => ["post-tag", "uri-id"],
			"uid" => ["post-user", "uid"],
			"iid" => ["post-user", "id"],
			"private" => ["post-user", "private"],
			"wall" => ["post-user", "wall"],
			"origin" => ["post-user", "origin"],
			"global" => ["post-user", "global"],
			"gravity" => ["post-user", "gravity"],
			"received" => ["post-user", "received"],
			"network" => ["post-user", "network"],
			"author-id" => ["post-user", "author-id"],
			"name" => ["tag", "name"],
		],
		"query" => "FROM `post-tag`
			INNER JOIN `tag` ON `tag`.`id` = `post-tag`.`tid`
			STRAIGHT_JOIN `post-user` ON `post-user`.`uri-id` = `post-tag`.`uri-id`
			WHERE `post-tag`.`type` = 1"
	],
	"workerqueue-view" => [
		"fields" => [
			"pid" => ["process", "pid"],
			"priority" => ["workerqueue", "priority"],
		],
		"query" => "FROM `process`
			INNER JOIN `workerqueue` ON `workerqueue`.`pid` = `process`.`pid`
			WHERE NOT `workerqueue`.`done`"
	],
	"profile_field-view" => [
		"fields" => [
			"id" => ["profile_field", "id"],
			"uid" => ["profile_field", "uid"],
			"label" => ["profile_field", "label"],
			"value" => ["profile_field", "value"],
			"order" => ["profile_field", "order"],
			"psid"=> ["profile_field", "psid"],
			"allow_cid" => ["permissionset", "allow_cid"],
			"allow_gid" => ["permissionset", "allow_gid"],
			"deny_cid" => ["permissionset", "deny_cid"],
			"deny_gid" => ["permissionset", "deny_gid"],
			"created" => ["profile_field", "created"],
			"edited" => ["profile_field", "edited"],
		],
		"query" => "FROM `profile_field`
			INNER JOIN `permissionset` ON `permissionset`.`id` = `profile_field`.`psid`"
	],
];

